#
# spec file for package evas
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           evas
Version:        1.7.4
Release:        15.1
Summary:        Canvas and scenegraph rendering library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  pkgconfig(gl)
BuildRequires:  SDL-devel
BuildRequires:  doxygen
BuildRequires:  eet-devel >= %version
BuildRequires:  eina-devel >= %version
BuildRequires:  fontconfig-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  giflib-devel
BuildRequires:  glibc-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel >= 1.2.10
BuildRequires:  librsvg2-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  libX11-devel
BuildRequires:  libXext-devel
BuildRequires:  libxcb-devel
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Evas is a clean display canvas API that implements a scene graph, not an immediate-mode rendering target, is cross-platform, for several target display systems that can draw anti-aliased text, smooth super and sub-sampled scaled images, alpha-blend objects and much more.

%package -n libevas1
Summary:        Evas Dynamic Libraries
Group:          System/Libraries
Requires:       %{name}-modules

%description -n libevas1
Headers, static libraries, test programs and documentation for eet

%package devel
Summary:        Evas headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       pkgconfig(gl)
Requires:       SDL-devel
Requires:       eet-devel >= %version
Requires:       eina-devel >= %version
Requires:       fontconfig-devel
Requires:       pkgconfig(freetype2)
Requires:       giflib-devel
Requires:       glibc-devel
Requires:       libevas1 = %{version}
Requires:       libjpeg-devel
Requires:       libpng-devel >= 1.2.10
Requires:       librsvg2-devel
Requires:       libtiff-devel
Requires:       libX11-devel
Requires:       libXext-devel
Requires:       libxcb-devel

%description devel
Headers, static libraries, test programs and documentation for evas

%package modules
Summary:        Evas modules
Group:          Development/Libraries/C and C++

%description modules
Evas modules containing loader, savers and engines.

%package doc-html
Summary:        HTML documentation of Evas
Group:          Documentation/HTML

%description doc-html
Documentation of Evas library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Evas
Group:          Documentation/Man

%description doc-man
Documentation of Evas library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%if 0%{?sles_version} >= 10
# old gcc without intristic
	%configure --disable-static --disable-cpu-sse3  --enable-image-loader-generic --enable-software-16-x11
%else
	%configure --disable-static --enable-image-loader-generic --enable-image-loader-svg --enable-software-16-x11
%endif
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;

if [ /usr/lib != %{_libexecdir} ] && [ -e %{buildroot}%{_prefix}/lib/dummy_slave ]; then
	mv %{buildroot}%{_prefix}/lib/evas* %{buildroot}%{_prefix}/lib/dummy_slave %{buildroot}%{_libexecdir}
fi

%post -n libevas1 -p /sbin/ldconfig
%postun -n libevas1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/evas_*

%files -n libevas1
%defattr(-, root, root)
%{_libdir}/libevas.so.*

%files modules
%defattr(-, root, root)
%dir %{_libdir}/evas/
%dir %{_libdir}/evas/modules/
%dir %{_libdir}/evas/modules/loaders/
%{_libdir}/evas/cserve2
%{_libdir}/evas/modules/engines
%{_libdir}/evas/modules/savers
%{_libdir}/evas/modules/loaders/bmp
%{_libdir}/evas/modules/loaders/eet
%{_libdir}/evas/modules/loaders/generic
%{_libdir}/evas/modules/loaders/gif
%{_libdir}/evas/modules/loaders/ico
%{_libdir}/evas/modules/loaders/jpeg
%{_libdir}/evas/modules/loaders/pmaps
%{_libdir}/evas/modules/loaders/png
%{_libdir}/evas/modules/loaders/psd
%{_libdir}/evas/modules/loaders/tga
%{_libdir}/evas/modules/loaders/tiff
%{_libdir}/evas/modules/loaders/wbmp
%{_libdir}/evas/modules/loaders/xpm

%files devel
%defattr(-, root, root)
%{_includedir}/evas-1/
%{_libdir}/pkgconfig/evas*.pc
%{_libdir}/libevas.so
%{_datadir}/evas/
%{_libexecdir}/evas_*
%{_libexecdir}/dummy_slave

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-15.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Evas 1.7.3:
  * Fix the gl line incorrect position drawing.
  * Fix uninitialized data in Evas_Smart initialization code.
  * Fix potential segv in software engine native_set call.
  * Fix uninitialized data in OpenGL engine native_set call.
  * Fix crash when precise_is_inside is set on an image, and
    events are generated from it.
  * Properly close async pipe fd on exec.
  * Fix the line drawing clipping problem on arm gl driver.
  * Fix big rendering/conversion problem in kvm/qemu 24bpp.
  * Fix Evas RGBA_Image->flags.loaded for copied images.
  * Fix evas_object_image_is_inside()
  * Fix small memory leak in evas_bidi_utils error path
* Thu Dec 20 2012 sleep_walker@suse.cz
- add man documentation as well
* Thu Dec 20 2012 sleep_walker@suse.cz
- build documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 22 2012 sleep_walker@suse.cz
- remove sles 10 and centos 5 conditions as we don't build for it anymore
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Wed Nov 14 2012 sleep_walker@suse.cz
- correct license to SPDX format
* Wed Nov 14 2012 sleep_walker@suse.cz
- remove autoupdate entries in changelog
- clean up the spec file a bit
* Sat Oct 20 2012 simon@simotek.net
- bump to 1.7.1
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file change makeinstall --> make_install
* Sat Aug 11 2012 sleep_walker@suse.cz
- alter to 1.7.0-alpha
* Mon Jul  9 2012 sleep_walker@suse.cz
- add egueb into dependencies for now
* Thu Jun 28 2012 sleep_walker@suse.cz
- fix naming
* Wed Jun 27 2012 sleep_walker@suse.cz
- enable esvg build since egueb is compiling fine
* Mon Jun 25 2012 sleep_walker@suse.cz
- add software_x11_16 engine to be loaded too
* Sun Jun 24 2012 sleep_walker@suse.cz
- fix the spec file until egueb will be ready
* Sat Jun 23 2012 sleep_walker@suse.cz
- accept modifications by cippp (thanks!)
* Tue Jun 12 2012 sleep_walker@suse.cz
- SLES10 doesn't have evas binaries in libexec dir
* Mon Jun 11 2012 sleep_walker@suse.cz
- fixed summary & description
* Fri Jun  8 2012 sleep_walker@suse.cz
- fix only libexec dir for distributions which don't use it
* Tue Jun  5 2012 sleep_walker@suse.cz
- libexecdir vs. libdir issue on i586 - /usr/lib/evas_cserve
* Fri May 18 2012 tcech@suse.com
- comment out new binaries for CentOS5
* Tue May 15 2012 sleep_walker@suse.cz
- adding new binaries to spec file
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Thu Dec 29 2011 sleep_walker@suse.cz
- change centos_version test for 505 (instead of 504)
* Mon Oct 24 2011 tcech@suse.com
- add forgotten Require for devel package
* Mon Oct 24 2011 tcech@suse.com
- add minimum required libpng-devel version to 1.2.10
  (which was verified by upstream)
* Tue Oct 18 2011 tcech@suse.com
- now condition is valid, but not correct - fixing
* Tue Oct 18 2011 tcech@suse.com
- fix incorrect condition
* Mon Oct 17 2011 tcech@suse.com
- fix build for SLES10 and CentOS 5
* Sun Oct 16 2011 tcech@suse.com
- add autoreconf before configure
* Sat Oct 15 2011 tcech@suse.com
- add all devel packages required for build as required for devel package
* Sat Oct 15 2011 tcech@suse.com
- explicitly require fontconfig-devel in devel package
* Fri Oct 14 2011 tcech@suse.com
- fix typo in RPM group
* Fri Oct 14 2011 tcech@suse.com
- fix condition to enable support for OpenGL
* Fri Oct  7 2011 tcech@suse.com
- fix build for RHEL-5 and CentOS 5
* Thu Oct  6 2011 jreidinger@suse.com
- bump version to 1.0.999.63877
* Wed Oct  5 2011 jreidinger@suse.com
- bump version to 1.0.999.63840
* Wed Oct  5 2011 tcech@suse.com
- add more dependencies (following README)
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 1.0.999.63807
* Mon Oct  3 2011 jreidinger@suse.com
- add svg and gif support
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package of evas, version 1.0.0
